@@ -13,7 +13,7 @@ try:
     from . import i18n
     from . import connect_core
     from . import log
-    # from . import screens
+    from . import screens
     from . import exceptions
     from . import command
     from . import check_value
@@ -25,7 +25,7 @@ except ModuleNotFoundError:
     import i18n
     import connect_core
     import log
-    # import screens
+    import screens
     import exceptions
     import command
     import check_value
@@ -40,7 +40,7 @@ class API:
             log_level: int = 0,
             screen_time_out: int = 0,
             screen_long_time_out: int = 0,
-            screen_post_timeout: int = 0,
+            screen_post_time_out: int = 0,
             connect_mode: int = 0,
             port: int = 0,
             log_handler=None,
@@ -88,8 +88,8 @@ class API:
             self.config.screen_timeout = screen_time_out
         if screen_long_time_out != 0:
             self.config.screen_long_timeout = screen_long_time_out
-        if screen_post_timeout != 0:
-            self.config.screen_post_timeout = screen_post_timeout
+        if screen_post_time_out != 0:
+            self.config.screen_post_timeout = screen_post_time_out
 
         if log_level == 0:
             log_level = self.config.log_level
@@ -194,11 +194,12 @@ class API:
             )
 
         self.connect_core = connect_core.API(self.config)
-        self._exist_board_list = []
+        self._exist_board_list = list()
         self._board_info_list = dict()
         self._ModeratorList = dict()
         self._LastThrowWaterBallTime = 0
         self._ThreadID = threading.get_ident()
+        self._goto_board_list = list()
 
         log.show_value(
             self.config,
@@ -322,6 +323,7 @@ class API:
             post_index: int = 0,
             search_type: int = 0,
             search_condition: str = None,
+            search_list: list = None,
             query: bool = False) -> data_type.PostInfo:
         self._one_thread()
 
@@ -340,6 +342,10 @@ class API:
             check_value.check(self.config, str,
                               'SearchCondition', search_condition)
 
+        if search_list is not None:
+            check_value.check(self.config, list,
+                              'search_list', search_condition)
+
         if len(board) == 0:
             raise ValueError(log.merge(
                 self.config,
@@ -410,8 +416,8 @@ class API:
                 data_type.index_type.BBS,
                 board=board,
                 search_type=search_type,
-                search_condition=search_condition
-            )
+                search_condition=search_condition,
+                search_list=search_list)
 
             if post_index < 1 or newest_index < post_index:
                 raise ValueError(log.merge(
@@ -435,6 +441,7 @@ class API:
                     post_index,
                     search_type,
                     search_condition,
+                    search_list,
                     query
                 )
             except exceptions.ParseError as e:
@@ -475,8 +482,9 @@ class API:
             self,
             board: str,
             check_moderator: bool = False) -> None:
+
         if board.lower() not in self._exist_board_list:
-            board_info = self._get_board_info(board)
+            board_info = self._get_board_info(board, False)
             self._exist_board_list.append(board.lower())
             self._board_info_list[board.lower()] = board_info
 
@@ -495,6 +503,7 @@ class API:
             post_index: int = 0,
             search_type: int = 0,
             search_condition: str = None,
+            search_list: list = None,
             query: bool = False) -> data_type.PostInfo:
 
         try:
@@ -509,6 +518,7 @@ class API:
             post_index,
             search_type,
             search_condition,
+            search_list,
             query)
 
     def _get_newest_index(
@@ -517,7 +527,8 @@ class API:
             board: str = None,
             # BBS
             search_type: int = 0,
-            search_condition: str = None) -> int:
+            search_condition: str = None,
+            search_list: list = None) -> int:
 
         check_value.check(
             self.config, int, 'index_type',
@@ -533,14 +544,16 @@ class API:
             index_type,
             board,
             search_type,
-            search_condition)
+            search_condition,
+            search_list)
 
     def get_newest_index(
             self,
             index_type: int,
             board: str = None,
             search_type: int = 0,
-            search_condition: str = None) -> int:
+            search_condition: str = None,
+            search_list: list = None) -> int:
         self._one_thread()
 
         if index_type == data_type.index_type.BBS or index_type == data_type.index_type.MAIL:
@@ -558,15 +571,10 @@ class API:
                 index_type,
                 board,
                 search_type,
-                search_condition)
+                search_condition,
+                search_list)
         except exceptions.NoSearchResult:
             raise exceptions.NoSearchResult
-        except Exception:
-            return self._get_newest_index(
-                index_type,
-                board,
-                search_type,
-                search_condition)
 
     def crawl_board(
             self,
@@ -580,6 +588,7 @@ class API:
             end_aid: str = None,
             search_type: int = 0,
             search_condition: str = None,
+            search_list: list = None,
             query: bool = False,
             # 網頁版本
             start_page: int = 0,
@@ -611,6 +620,11 @@ class API:
             if search_condition is not None:
                 check_value.check(self.config, str,
                                   'SearchCondition', search_condition)
+
+            if search_list is not None:
+                check_value.check(self.config, list,
+                                  'search_list', search_list)
+
             if start_aid is not None:
                 check_value.check(self.config, str, 'StartAID', start_aid)
             if end_aid is not None:
@@ -714,8 +728,8 @@ class API:
                 end_index
             )
 
-            error_post_list = []
-            del_post_list = []
+            error_post_list = list()
+            del_post_list = list()
             if self.config.log_level == log.level.INFO:
                 PB = progressbar.ProgressBar(
                     max_value=end_index - start_index + 1,
@@ -732,6 +746,7 @@ class API:
                             post_index=index,
                             search_type=search_type,
                             search_condition=search_condition,
+                            search_list=search_list,
                             query=query
                         )
                     except exceptions.ParseError as e:
@@ -824,8 +839,7 @@ class API:
             # 1. 取得總共有幾頁 MaxPage
             newest_index = self._get_newest_index(
                 data_type.index_type.WEB,
-                board=board
-            )
+                board=board)
             # 2. 檢查 StartPage 跟 EndPage 有沒有在 1 ~ MaxPage 之間
 
             check_value.check_index_range(
@@ -838,8 +852,8 @@ class API:
             )
 
             # 3. 把每篇文章(包括被刪除文章)欄位解析出來組合成 data_type.PostInfo
-            error_post_list = []
-            del_post_list = []
+            error_post_list = list()
+            del_post_list = list()
             # PostAID = ""
             _url = 'https://www.ptt.cc/bbs/'
             index = str(newest_index)
@@ -1026,8 +1040,7 @@ class API:
         if post_index != 0:
             newest_index = self._get_newest_index(
                 data_type.index_type.BBS,
-                board=board
-            )
+                board=board)
             check_value.check_index(self.config, 'PostIndex',
                                     post_index, newest_index)
 
@@ -1071,34 +1084,26 @@ class API:
                     i18n.not_push_aligned)
                 max_push_length = 58 - len(self._ID)
 
-        push_list = []
+        push_content = push_content.strip()
 
-        temp_start_index = 0
-        temp_end_index = temp_start_index + 1
+        push_list = list()
+        while push_content:
+            index = 0
+            jump = 0
 
-        while temp_end_index <= len(push_content):
+            while len(push_content[:index].encode('big5-uao', 'replace')) < max_push_length:
 
-            temp = ''
-            last_temp = None
-            while len(temp.encode('big5-uao', 'replace')) < max_push_length:
-                temp = push_content[temp_start_index:temp_end_index]
-
-                if not len(temp.encode('big5-uao', 'replace')) < max_push_length:
+                if index == len(push_content):
                     break
-                elif push_content.endswith(temp):
-                    break
-                elif temp.endswith('\n'):
-                    break
-                elif last_temp == temp:
+                if push_content[index] == '\n':
+                    jump = 1
                     break
 
-                temp_end_index += 1
-                last_temp = temp
+                index += 1
 
-            push_list.append(temp.strip())
+            push_list.append(push_content[:index])
+            push_content = push_content[index + jump:]
 
-            temp_start_index = temp_end_index
-            temp_end_index = temp_start_index + 1
         push_list = filter(None, push_list)
 
         for push in push_list:
@@ -1106,8 +1111,7 @@ class API:
                 self.config,
                 log.level.INFO,
                 i18n.Push,
-                push
-            )
+                push)
 
             for _ in range(2):
                 try:
@@ -1116,16 +1120,14 @@ class API:
                         push_type,
                         push,
                         post_aid=post_aid,
-                        post_index=post_index
-                    )
+                        post_index=post_index)
                     break
                 except exceptions.NoFastPush:
                     # screens.show(self.config, self.connect_core.getScreenQueue())
                     log.log(
                         self.config,
                         log.level.INFO,
-                        '等待快速推文'
-                    )
+                        '等待快速推文')
                     time.sleep(5.2)
 
     def _push(
@@ -1616,7 +1618,7 @@ class API:
 
         return _api_search_user.search_user(self, ptt_id, min_page, max_page)
 
-    def get_board_info(self, board: str) -> data_type.BoardInfo:
+    def get_board_info(self, board: str, get_post_kind: bool = False) -> data_type.BoardInfo:
 
         self._one_thread()
 
@@ -1627,16 +1629,16 @@ class API:
 
         check_value.check(self.config, str, 'board', board)
 
-        return self._get_board_info(board, call_by_others=False)
+        return self._get_board_info(board, get_post_kind, call_by_others=False)
 
-    def _get_board_info(self, board: str, call_by_others: bool = True) -> data_type.BoardInfo:
+    def _get_board_info(self, board: str, get_post_kind, call_by_others: bool = True) -> data_type.BoardInfo:
 
         try:
             from . import _api_get_board_info
         except ModuleNotFoundError:
             import _api_get_board_info
 
-        return _api_get_board_info.get_board_info(self, board, call_by_others)
+        return _api_get_board_info.get_board_info(self, board, get_post_kind, call_by_others)
 
     def get_mail(self, index):
 
@@ -1746,7 +1748,55 @@ class API:
 
         return board, aid
 
+    def _goto_board(self, board: str, refresh: bool = False) -> None:
+
+        cmd_list = list()
+        cmd_list.append(command.GoMainMenu)
+        cmd_list.append('qs')
+        cmd_list.append(board)
+        cmd_list.append(command.Enter)
+        cmd_list.append(command.Space)
+
+        cmd = ''.join(cmd_list)
+
+        target_list = [
+            connect_core.TargetUnit(
+                i18n.AnyKeyContinue,
+                '任意鍵',
+                response=' ',
+                log_level=log.level.DEBUG
+            ),
+            connect_core.TargetUnit(
+                [
+                    '動畫播放中',
+                ],
+                '互動式動畫播放中',
+                response=command.Ctrl_C,
+                log_level=log.level.DEBUG
+            ),
+            connect_core.TargetUnit(
+                [
+                    '進板成功',
+                ],
+                screens.Target.InBoard,
+                break_detect=True,
+                log_level=log.level.DEBUG
+            ),
+        ]
+
+        if refresh:
+            current_refresh = True
+        else:
+            if board.lower() in self._goto_board_list:
+                current_refresh = True
+            else:
+                current_refresh = False
+        self._goto_board_list.append(board.lower())
+
+        self.connect_core.send(cmd, target_list, refresh=current_refresh)
+
 
 if __name__ == '__main__':
     print('PyPtt v ' + version.V)
     print('Developed by CodingMan')
+    print('Github: PttCodingMan')
