@@ -21,7 +21,7 @@ except ModuleNotFoundError:
 
 
 def logout(api) -> None:
-    cmd_list = []
+    cmd_list = list()
     cmd_list.append(command.GoMainMenu)
     cmd_list.append('g')
     cmd_list.append(command.Enter)
@@ -232,9 +232,14 @@ def login(
             '另外若輸入後發生認證碼錯誤請先確認輸入是否為最後一封',
             response='x' + command.Enter
         ),
+        connect_core.TargetUnit(
+            i18n.SkipRegistrationForm,
+            '此帳號已設定為只能使用安全連線',
+            exceptions_=exceptions.OnlySecureConnection()
+        )
     ]
 
-    cmd_list = []
+    cmd_list = list()
     cmd_list.append(ptt_id)
     cmd_list.append(command.Enter)
     cmd_list.append(password)
