@@ -186,6 +186,7 @@ timeout = None
 NoSearchResult = None
 SkipRegistrationForm = None
 url = None
+OnlySecureConnection = None
 
 
 def specific_load(input_language, lang_list):
@@ -1231,12 +1232,18 @@ def load(input_lang):
         'url',
     ])
 
+    global OnlySecureConnection
+    OnlySecureConnection = specific_load(input_lang, [
+        '已設定為只能使用安全連線',
+        'Secure connections only',
+    ])
+
     # No changes have been made to any settings
 
     # Quote original
 
     # global List
-    # List = []
+    # List = list()
 
     # for k, v in globals().items():
     #     # System Var
@@ -1250,7 +1257,7 @@ def load(input_lang):
 
 
 def _createlist():
-    i18nStrList = []
+    i18nStrList = list()
 
     for k, v in globals().items():
         # System Var
